Maintenance — SatNOGS DB 1.63 documentation

# Maintenance

## Updating Python dependencies

To update the Python dependencies:

1. Execute script to refresh `requirements{-dev}.txt` files:

       $ ./contrib/refresh-requirements.sh

2. Stage and commit `requirements{-dev}.txt` files.

## Updating frontend dependencies

The frontend dependencies are managed with `npm`. To update the frontend dependencies, while respecting semver:

1. Update all the packages listed in `package.json`:

       $ npm update

2. Test and copy the newly downlodaded static assets:

       $ ./node_modules/.bin/gulp

3. Stage and commit `package-lock.json` file.